==> haskell-hls-alternate-number-format-plugin-2.1.0.0-59-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-alternate-number-format-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-alternate-number-format-plugin
version:              2.1.0.0
visibility:           public
id:
    hls-alternate-number-format-plugin-2.1.0.0-3p1qPzlj1aNFR7PXOemsbY

key:
    hls-alternate-number-format-plugin-2.1.0.0-3p1qPzlj1aNFR7PXOemsbY

license:              Apache-2.0
maintainer:           nicksuchecki@gmail.com
author:               Nick Suchecki
synopsis:
    Provide Alternate Number Formats plugin for Haskell Language Server

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  1240ffc79b0b2c60d27d5a4d677efcc3
exposed:              True
exposed-modules:
    Ide.Plugin.AlternateNumberFormat Ide.Plugin.Conversion

hidden-modules:       Ide.Plugin.Literals
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-alternate-number-format-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-alternate-number-format-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-alternate-number-format-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-alternate-number-format-plugin
hs-libraries:
    HShls-alternate-number-format-plugin-2.1.0.0-3p1qPzlj1aNFR7PXOemsbY

depends:
    aeson-2.1.2.1-6FuMYI3vdPa8Ts5NPsnpCg base-4.17.2.1 containers-0.6.7
    extra-1.7.16-KxrHBQWVwMp2M62XitBte8 ghc-boot-th-9.4.8
    ghcide-2.1.0.0-7mveeBu1NdO3tDaPLTwSr0
    hie-compat-0.3.1.1-EX7c63LZz6m3PpO1VmTjuM
    hls-graph-2.1.0.0-E0uwKa062XbErlHzLpQDMc
    hls-plugin-api-2.1.0.0-2mMBQBjk997A47exxFPkZd
    lens-5.3.1-57CGCDOUfQCLkJSlnZcVUR
    lsp-2.1.0.0-GxokUjVxBLy4j05JlhgdFg mtl-2.2.2
    regex-tdfa-1.3.2.4-9ZyuPp8BFYO5HpZyySDZc8
    syb-0.7.3-Lap6GPARkRXCVbqA2faY6P text-2.0.2
    unordered-containers-0.2.20-89DcpQLd7HI30AdGz5XyJk

haddock-interfaces:
    /usr/share/doc/haskell-hls-alternate-number-format-plugin/html/hls-alternate-number-format-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-alternate-number-format-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-alternate-number-format-plugin-2.1.0.0-94-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-alternate-number-format-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-alternate-number-format-plugin
version:              2.1.0.0
visibility:           public
id:
    hls-alternate-number-format-plugin-2.1.0.0-IJTjNVldD0b8ZmnMfKl2Pr

key:
    hls-alternate-number-format-plugin-2.1.0.0-IJTjNVldD0b8ZmnMfKl2Pr

license:              Apache-2.0
maintainer:           nicksuchecki@gmail.com
author:               Nick Suchecki
synopsis:
    Provide Alternate Number Formats plugin for Haskell Language Server

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  208ca01bd08a3150a57365665c6d7d95
exposed:              True
exposed-modules:
    Ide.Plugin.AlternateNumberFormat Ide.Plugin.Conversion

hidden-modules:       Ide.Plugin.Literals
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-alternate-number-format-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-alternate-number-format-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-alternate-number-format-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-alternate-number-format-plugin
hs-libraries:
    HShls-alternate-number-format-plugin-2.1.0.0-IJTjNVldD0b8ZmnMfKl2Pr

depends:
    aeson-2.1.2.1-3HLieqpkeG06w6MDAYdLLk base-4.17.2.1 containers-0.6.7
    extra-1.7.16-CyTEZvSfBxsKCwY9ZtJE7E ghc-boot-th-9.4.8
    ghcide-2.1.0.0-EGobQkKgR8zaeADYgxOC5
    hie-compat-0.3.1.1-EX7c63LZz6m3PpO1VmTjuM
    hls-graph-2.1.0.0-7LnpvrkjhrNH9iznMLZXCG
    hls-plugin-api-2.1.0.0-EfBvd6pBF3is65S9wzuFu
    lens-5.3.3-1zYcQilqoBK5EhYwkXjOnb
    lsp-2.1.0.0-4wEItkatDyfAFCzTPH6SAN mtl-2.2.2
    regex-tdfa-1.3.2.5-71D7aDzS2d23Ft8PQEnlRo
    syb-0.7.3-C5AaeelSWDKGvBUWTjIxkt text-2.0.2
    unordered-containers-0.2.20.1-JRJBW0Nl9iEJULI134IWXM

haddock-interfaces:
    /usr/share/doc/haskell-hls-alternate-number-format-plugin/html/hls-alternate-number-format-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-alternate-number-format-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
